<?

/***************************************************************************************
 * Filename: navigation.php
 *
 * This file is part of the Navigation JAS plugin.
 * Copyright 2003-2016 by Matthijs Schuurman
 *
 * The Navigation JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/navigation/
 ***************************************************************************************/


 require_once($_path["include"]."data.php");
 require_once($_path["format"]."template.php");
 require_once($_path["plugins"]."lister/lister.php");

 class Plugin_navigation extends Plugin_lister
 {
  function _getData()
  {
   global $_benchmark;

   if(!$this->config)
    return false;

   if($_benchmark) $_benchmark->start("Data object");

   $d=Data::cache("pager_categories", "tree", "down");
   $d->clearValues();

   //set field values so lister->cache takes these in to account when checking cache
   $d->setValue("disabled", false);
   $d->setValue("catnr", $this->config["listcatnr"]);

   if($this->config["treedepth"])
    $d->setValue("treedepth", $this->config["treedepth"]-1);

   $d->sortOrder("ordernr", "name");

   if($_benchmark) $_benchmark->stop("Data object");

   return $d;
  }


  function cache(&$cacheTime, &$cacheKey)
  {
   if($page=request("p", 0))
   {
    $page=preg_replace("/[^A-Za-z0-9_]/", "", $page); //remove special characters
    $cacheKey.=$page."_"; //add page name so caching is unique for each page (needed for active flag)
   }

   if(!parent::cache($cacheTime, $cacheKey))
    return false;

   return true;
  }


  function output()
  {
   global $_path, $_config, $_benchmark;

   if($_benchmark) $_benchmark->start("Get content");

   if(!($d=$this->_getData()))
    return false;

   $id=$d->getID();

   if($_config->get("useModRewrite")) //mod rewrite
   {
    $d->addField("base_url", "text", "", "control", 0, false, $_path["HTML"]["current"]);
    $d->addField("root_url", "text", "", "control", 0, false, $_path["root"]);

    $tmp=$_path["HTML"]["current"];
    foreach($this->plugin->vars as $k => $v)
     if($k=="p"||substr($k, 0, 2)=="p[")
      $tmp.=$v."/";

    $d->addField("page_url", "text", "", "control", 0, false, $tmp);

    unset($tmp);
   }
   else
   {
    $d->addField("base_url", "text", "", "control", 0, false, "");
    $d->addField("root_url", "text", "", "control", 0, false, $_path["root"]);
   }

   $d->addField("level", "nr", "", "", 0, false, 1);
   $d->addField("active", "boolean", "", "", false, false, false);

   //load template
   if($this->config["templatelist"])
    $templateFile=$_path["project"]["templates"].$this->config["templatelist"];
   else
    $templateFile=$this->plugin->path["templates"].$this->plugin->templatelist;

   if($_benchmark) $_benchmark->start("Template");

   $template=new Format_Template(true);

   if(!$template->read($templateFile)||!$template->analyze($d))
   {
    $this->e->add($template->e);
    return false;
   }

   if($template->markerExists("_fields")&&$this->config["showfields"]) //_fields marker in template and predefined fields set
    $d->setShowFields(array_merge($this->config["showfields"], $d->check("use", "show"))); //added predefined fields to show fields
   //else //use template defined fields

   if($_benchmark) $_benchmark->stop("Template");

   if($_benchmark) $_benchmark->start("Get data");

   //get data
   if(!$d->get($template->getLevel()))
   {
    $this->e->add($d->e);
    return false;
   }

   //set base_url and root_url values
   for($c=0;$c<$d->vmax;$c++)
   {
    $d->setDefaultValue("base_url", $c);
    $d->setDefaultValue("root_url", $c);
    $d->setValue("level", $d->getValue("treedepth", $c)+2, $c);

    //active flag
    if($d->getValue("urlname", $c)==request("p", 0))
    {
     $d->setValue("active", true, $c);

     //sub level active, activate all upper levels
     if($d->getValue("treedepth", $c)>0)
     {
      $current=$d->getValue("treedepth", $c);
      for($x=$c-1;$x>=0;$x--)
      {
       if($d->getValue("treedepth", $x)<$current)
       {
        $d->setValue("active", true, $x);
        $current=$d->getValue("treedepth", $x);
       }
      }
     }
    }
    else
     $d->setValue("active", false, $c);

   }

   if($_benchmark) $_benchmark->stop("Get data");
   if($_benchmark) $_benchmark->start("Populate template");

   if(!$template->populate())
   {
    $this->e->add($template->e);
    return false;
   }

   $output=$template->output();

   if($_benchmark) $_benchmark->stop("Populate template");

   if($_benchmark) $_benchmark->stop("Get content");

   return $output;
  }

 }
?>
